import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface TurnstileWidgetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#account_id TurnstileWidget#account_id}
    */
    readonly accountId: string;
    /**
    * If bot_fight_mode is set to true, Cloudflare issues computationally expensive challenges in response to malicious bots (Enterprise only).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#bot_fight_mode TurnstileWidget#bot_fight_mode}
    */
    readonly botFightMode?: boolean | cdktf.IResolvable;
    /**
    * Domains where the widget is deployed
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#domains TurnstileWidget#domains}
    */
    readonly domains: string[];
    /**
    * The identifier of this resource. This is the site key value.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#id TurnstileWidget#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Widget Mode. Available values: `non-interactive`, `invisible`, `managed`
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#mode TurnstileWidget#mode}
    */
    readonly mode: string;
    /**
    * Human readable widget name.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#name TurnstileWidget#name}
    */
    readonly name: string;
    /**
    * Do not show any Cloudflare branding on the widget (Enterprise only).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#offlabel TurnstileWidget#offlabel}
    */
    readonly offlabel?: boolean | cdktf.IResolvable;
    /**
    * Region where this widget can be used.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget#region TurnstileWidget#region}
    */
    readonly region?: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget cloudflare_turnstile_widget}
*/
export declare class TurnstileWidget extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_turnstile_widget";
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.6.0/docs/resources/turnstile_widget cloudflare_turnstile_widget} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options TurnstileWidgetConfig
    */
    constructor(scope: Construct, id: string, config: TurnstileWidgetConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _botFightMode?;
    get botFightMode(): boolean | cdktf.IResolvable;
    set botFightMode(value: boolean | cdktf.IResolvable);
    resetBotFightMode(): void;
    get botFightModeInput(): boolean | cdktf.IResolvable | undefined;
    private _domains?;
    get domains(): string[];
    set domains(value: string[]);
    get domainsInput(): string[] | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _mode?;
    get mode(): string;
    set mode(value: string);
    get modeInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _offlabel?;
    get offlabel(): boolean | cdktf.IResolvable;
    set offlabel(value: boolean | cdktf.IResolvable);
    resetOfflabel(): void;
    get offlabelInput(): boolean | cdktf.IResolvable | undefined;
    private _region?;
    get region(): string;
    set region(value: string);
    resetRegion(): void;
    get regionInput(): string | undefined;
    get secret(): string;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
